Method: Rasem::SVGPath#arcTo
- Defined in:
- lib/rasem/svg_image.rb
#arcTo(dx, dy, rx, ry, axis_rotation, large_arc_flag, sweep_flag) ⇒ Object
elliptical arc commands
Draws an elliptical arc from the current point to the point x,y. rx and ry are the elliptical radius in x and y direction. The x-rotation determines how much the arc is to be rotated around the x-axis. It only seems to have an effect when rx and ry have different values. The large-arc-flag doesn't seem to be used (can be either 0 or 1). Neither value (0 or 1) changes the arc. The sweep-flag determines the direction to draw the arc in.
683 684 685 |
# File 'lib/rasem/svg_image.rb', line 683 def arcTo(dx, dy, rx, ry, axis_rotation, large_arc_flag, sweep_flag) add_d("a#{rx},#{ry} #{axis_rotation} #{large_arc_flag},#{sweep_flag} #{dx},#{dy}") end |